@@ -37,7 +37,6 @@ class Plot : public Lum::Component, public ConfigPlugin
 private:
   /* Plotter */
   FunctionsRef             functions;
-  Lum::Model::ListTableRef history;
   Lum::Model::ActionRef    editFunctions;
   Lum::Model::ActionRef    autosize;
   Lum::Model::ActionRef    region;
@@ -52,7 +51,6 @@ private:
 
 public:
   Plot();
-  ~Plot();
 
   void CalcSize();
 
